mpxplugins/viewplugins/views/collectionviewhg/inc/mpxcollectionviewhgimp.h
branchRCL_3
changeset 15 171e07ac910f
parent 14 943ff5625028
child 18 c54d95799c80
--- a/mpxplugins/viewplugins/views/collectionviewhg/inc/mpxcollectionviewhgimp.h	Fri Mar 12 15:42:25 2010 +0200
+++ b/mpxplugins/viewplugins/views/collectionviewhg/inc/mpxcollectionviewhgimp.h	Mon Mar 15 12:40:11 2010 +0200
@@ -21,7 +21,7 @@
 
 // INCLUDES
 #include <eikclb.h>
-#include <AknProgressDialog.h>  // MProgressDialogCallback
+#include <aknwaitdialog.h>
 #include <eikprogi.h>
 #include <mpxmediageneraldefs.h>
 #include <mpxcollectionobserver.h>
@@ -203,18 +203,17 @@
     void StartWaitNoteL( TWaitNoteType aNoteType );
 
     /**
      * Start either the delete progress note
      *
      */
-    void StartProgressNoteL();
+    void StartDeleteWaitNoteL();
 
     /**
      * Updates the progress note text and progress bar
      *
-     * @param aProgress Indicates the portion of the process completed
      * @param aProgressText Text to be displayed on the progress note
      */
-    void UpdateProcessL( TInt aProgress, const TDesC& aProgressText );
+    void UpdateProcessL( const TDesC& aProgressText );
 
     /**
     * Close a wait note
@@ -843,7 +842,8 @@
  	 * Stores the current list box item index.
  	 */
  	void StoreListboxItemIndexL();
-
+ 	
+ 	void ShowAddedItemsDialogL();
 
  	/*
  	 * Internal function for registering to BackStepping service.
@@ -904,7 +904,7 @@
     TBool                       iIgnoreNextFocusChangedMessage;
     TBool                       iCollectionReady;  // for incremental open
     TBool                       iCollectionCacheReady; //cache ready
-
+    
     TInt                        iCurrentPlaylistOp;
     TInt                        iNumSongAddedToPlaylist;
     TMPXItemId                  iPlaylistId;
@@ -982,9 +982,8 @@
     TInt iMusicStoreWebPage;
     HBufC16* iOperatorMusicStoreURI;
 
-    // Progress note for delete
-    CAknProgressDialog*	iProgressDialog;
-    CEikProgressInfo*	iProgressInfo;
+    // Wait note for delete
+    CAknWaitDialog*	iWaitDialog;
     TBool iIsAddingToPlaylist;  // flag used to handle the return by adding songs incrementally
     CUpnpCopyCommand* iUpnpCopyCommand;
 
@@ -992,6 +991,9 @@
 	TBool iMarkedAll;
 	TBool iFirstIncrementalBatch;
     CMPXMedia *iStoredAlbum; // owned
+    
+    TBool                       iDialogDismissed;
+    HBufC*                      iTitleWait; // Owned
     };
 
 #endif  // C_CMPXCOLLECTIONVIEWHGIMP_H
@@ -203,18 +203,17 @@
 
     /**
-     * Start either the delete progress note
+     * Start either the delete wait note
      *
      */